summaryrefslogtreecommitdiff
path: root/autogen.sh
diff options
context:
space:
mode:
authorJan Nieuwenhuizen <janneke@gnu.org>2002-06-18 15:46:03 +0000
committerJan Nieuwenhuizen <janneke@gnu.org>2002-06-18 15:46:03 +0000
commit38655bc28e73a0b218ba1582bdb84bab0fdfec4b (patch)
tree44f9049304684992b7587ef01cb410f2e0e6b69a /autogen.sh
parent17912cfaa97a8c3159026435db295c055a977270 (diff)
* Documentation/windows/zlily-profile.sh:
* Documentation/windows/post-lilypond.sh: Assume normal prefix=/usr for lilypond. * lily/musical-request.cc (length_mom): Display origin with error. * lily/lily-guile.cc (ly_pair_p): [PARANOID]: Check for freed cells. * lily/part-combine-music-iterator.cc (get_state): Bugfix: use ly_symbol2scm to get a scm symbol (rather than ly_str02scm). * aclocal.m4: * autogen.sh: Regenerate. * Documentation/topdocs/INSTALL.texi: * configure.in: * stepmake/configure.in: * stepmake/aclocal.m4: Revert autoconf upgrade. Autoconf 2.53 has a serious bug wrt AC_CONFIG_AUX_DIR (reported). Creating ./configure once again requires autoconf == 2.13. * stepmake/autogen.sh: Check for autoconf == 2.13.
Diffstat (limited to 'autogen.sh')
-rwxr-xr-xautogen.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/autogen.sh b/autogen.sh
index c9128e998d..4cc98ffdf7 100755
--- a/autogen.sh
+++ b/autogen.sh
@@ -6,23 +6,23 @@
srcdir=`dirname $0`
# Be paranoid: check for autoconf >= 2.50
# Some setups have both autoconf 2.13 and 2.50 available through
# a wrapper script: /usr/bin/autoconf.
-# This wrapper may correctly autoselect autoconf 2.50, but it
+# This wrapper may incorrectly autoselect autoconf 2.50, but it
# advertises itself as autoconf 2.13.
# If you have such a setup, invoke this script as:
-# autoconf=autoconf ./autogen.sh
-for i in in autoconf autoconf2.50 false; do
+# autoconf=autoconf2.13 ./autogen.sh
+for i in autoconf autoconf2.13 false; do
version=`$i --version 2>/dev/null | head -1 | awk '{print $NF}' | awk -F. '{print $1 * 100 + $2}'`
- if test "0$version" -ge 250; then
+ if test "0$version" -eq 213; then
autoconf=$i
break
fi
done
if test -z "$autoconf"; then
- echo "ERROR: Please install autoconf 2.50 or newer"
+ echo "ERROR: Please install autoconf 2.13"
exit 1
fi
@@ -6,23 +6,23 @@
srcdir=`dirname $0`
-# Be paranoid: check for autoconf >= 2.50
+# Be paranoid: check for autoconf == 2.13
# Some setups have both autoconf 2.13 and 2.50 available through
# a wrapper script: /usr/bin/autoconf.